@@ -103,7 +103,7 @@ conTest <- function(object, constraints = NULL, type = "summary", test = "F",
       ldots$se <- "none"
     }
     
-    m.restr <- match(names(ldots), c("se", "B", "mix.weights", "mix.bootstrap", #"bootmix.weights",
+    m.restr <- match(names(ldots), c("se", "B", "mix_weights", 
                                      "parallel", "ncpus", "cl", "seed", "control", 
                                      "verbose", "debug"), 0L)
     
