@@ -17,7 +17,7 @@ conTestF.conRLM <- function(object, type = "A", neq.alt = 0, boot = "no", R = 99
   if(!(type %in% c("A","B","global"))) {
     stop("Restriktor ERROR: type must be \"A\", \"B\", or \"global\"")
   }
-  if(!(boot %in% c("no", "residual", "model.based", "parametric", "mix.weights"))) {
+  if(!(boot %in% c("no", "residual", "model.based", "parametric"))) {
     stop("Restriktor ERROR: boot method unknown.")
   }
   if (boot == "residual") {
@@ -173,10 +173,20 @@ conTestF.conRLM <- function(object, type = "A", neq.alt = 0, boot = "no", R = 99
                               bvec        = bvec, 
                               meq         = meq, 
                               meq.alt     = meq.alt)
-    #wt.mix <- wt.bar
-    #attributes(wt.mix) <- NULL
-    attr(pvalue, "wt.bar") <- wt.bar
-    attr(pvalue, "wt.bar.method") <- attr(wt.bar, "method")
+  
+    attr(pvalue, "wt.bar"                     ) <- as.numeric(wt.bar)
+    attr(pvalue, "wt.bar.method"              ) <- attr(wt.bar, "method")
+    attr(pvalue, "converged"                  ) <- attr(wt.bar, "converged")
+    attr(pvalue, "convergence_crit"           ) <- attr(wt.bar, "convergence_crit")
+    attr(pvalue, "total_bootstrap_draws"      ) <- attr(wt.bar, "total_bootstrap_draws")
+    attr(pvalue, "error.idx"                  ) <- attr(wt.bar, "error.idx")
+    attr(pvalue, "mix_weights_bootstrap_limit") <- attr(wt.bar, "mix_weights_bootstrap_limit")
+    
+    attr(pvalue, "wt_bar_chunk") <- attr(wt.bar, "wt_bar_chunk")
+    attr(pvalue, "chunk_size"  ) <- attr(wt.bar, "chunk_size_org")
+    attr(pvalue, "total_chunks") <- attr(wt.bar, "total_chunks")
+    attr(pvalue, "chunk_iter"  ) <- attr(wt.bar, "chunk_iter")
+    
   } else if (boot == "parametric") {
     
     if (!is.function(p.distr)) {
@@ -268,7 +278,7 @@ conTestWald.conRLM <- function(object, type = "A", neq.alt = 0, boot = "no", R =
   if(!(type %in% c("A","B","global"))) {
     stop("Restriktor ERROR: type must be \"A\", \"B\", or \"global\"")
   }
-  if(!(boot %in% c("no", "residual", "model.based", "parametric", "mix.weights"))) {
+  if(!(boot %in% c("no", "residual", "model.based", "parametric"))) {
     stop("Restriktor ERROR: boot method unknown.")
   }
   if (boot == "residual") {
@@ -429,7 +439,20 @@ conTestWald.conRLM <- function(object, type = "A", neq.alt = 0, boot = "no", R =
                               bvec        = bvec, 
                               meq         = meq, 
                               meq.alt     = meq.alt)
-    attr(pvalue, "wt.bar") <- wt.bar
+    
+    attr(pvalue, "wt.bar"                     ) <- as.numeric(wt.bar)
+    attr(pvalue, "wt.bar.method"              ) <- attr(wt.bar, "method")
+    attr(pvalue, "converged"                  ) <- attr(wt.bar, "converged")
+    attr(pvalue, "convergence_crit"           ) <- attr(wt.bar, "convergence_crit")
+    attr(pvalue, "total_bootstrap_draws"      ) <- attr(wt.bar, "total_bootstrap_draws")
+    attr(pvalue, "error.idx"                  ) <- attr(wt.bar, "error.idx")
+    attr(pvalue, "mix_weights_bootstrap_limit") <- attr(wt.bar, "mix_weights_bootstrap_limit")
+    
+    attr(pvalue, "wt_bar_chunk") <- attr(wt.bar, "wt_bar_chunk")
+    attr(pvalue, "chunk_size"  ) <- attr(wt.bar, "chunk_size_org")
+    attr(pvalue, "total_chunks") <- attr(wt.bar, "total_chunks")
+    attr(pvalue, "chunk_iter"  ) <- attr(wt.bar, "chunk_iter")
+    
   } else if (boot == "parametric") {
     if (!is.function(p.distr)) {
       p.distr <- get(p.distr, mode = "function")
@@ -518,7 +541,7 @@ conTestScore.conRLM <- function(object, type = "A", neq.alt = 0, boot = "no", R
   if(!(type %in% c("A","B","global"))) {
     stop("Restriktor ERROR: type must be \"A\", \"B\", or \"global\"")
   }  
-  if(!(boot %in% c("no", "residual", "model.based", "parametric", "mix.weights"))) {
+  if(!(boot %in% c("no", "residual", "model.based", "parametric"))) {
     stop("Restriktor ERROR: boot method unknown.")
   }  
   if (boot == "residual") {
@@ -694,13 +717,14 @@ conTestScore.conRLM <- function(object, type = "A", neq.alt = 0, boot = "no", R
       wt.bar <- con_weights_boot(VCOV     = V,
                                  Amat     = Amat, 
                                  meq      = meq, 
-                                 R        = attr(object$wt.bar, "mix.bootstrap"),
-                                 parallel = parallel, 
-                                 ncpus    = ncpus, 
-                                 cl       = cl,
+                                 R        = attr(object$wt.bar, "mix_weights_bootstrap_limit"),
                                  seed     = seed,
-                                 verbose  = verbose)
-      attr(wt.bar, "mix.bootstrap") <- attr(object$wt.bar, "mix.bootstrap")
+                                 convergence_crit = ifelse(is.null(control$convergence_crit), 
+                                                           1e-03, control$convergence_crit),
+                                 chunk_size = ifelse(is.null(control$chunk_size), 
+                                                           5000L, control$chunk_size),
+                                 verbose = verbose)
+      attr(wt.bar, "mix_weights_bootstrap_limit") <- attr(object$wt.bar, "mix_weights_bootstrap_limit")
     } else if (attr(object$wt.bar, "method") == "pmvnorm" && (meq < nrow(Amat))) {
       # compute chi-square-bar weights based on pmvnorm
       wt.bar <- rev(con_weights(Amat %*% V %*% t(Amat), meq = meq))
@@ -720,7 +744,20 @@ conTestScore.conRLM <- function(object, type = "A", neq.alt = 0, boot = "no", R
                               bvec        = bvec, 
                               meq         = meq, 
                               meq.alt     = meq.alt)
-    attr(pvalue, "wt.bar") <- wt.bar
+    
+    attr(pvalue, "wt.bar"                     ) <- as.numeric(wt.bar)
+    attr(pvalue, "wt.bar.method"              ) <- attr(wt.bar, "method")
+    attr(pvalue, "converged"                  ) <- attr(wt.bar, "converged")
+    attr(pvalue, "convergence_crit"           ) <- attr(wt.bar, "convergence_crit")
+    attr(pvalue, "total_bootstrap_draws"      ) <- attr(wt.bar, "total_bootstrap_draws")
+    attr(pvalue, "error.idx"                  ) <- attr(wt.bar, "error.idx")
+    attr(pvalue, "mix_weights_bootstrap_limit") <- attr(wt.bar, "mix_weights_bootstrap_limit")
+    
+    attr(pvalue, "wt_bar_chunk") <- attr(wt.bar, "wt_bar_chunk")
+    attr(pvalue, "chunk_size"  ) <- attr(wt.bar, "chunk_size_org")
+    attr(pvalue, "total_chunks") <- attr(wt.bar, "total_chunks")
+    attr(pvalue, "chunk_iter"  ) <- attr(wt.bar, "chunk_iter")
+    
   } else if (boot == "parametric") {
     if (!is.function(p.distr)) {
       p.distr <- get(p.distr, mode = "function")
