@@ -3,5 +3,9 @@
                       fields="Version")
     packageStartupMessage("This is ",paste(pkgname, version))
     #packageStartupMessage(pkgname, " is BETA software! Please report any bugs.")
-    packageStartupMessage("Please report any bugs.")
-}
\ No newline at end of file
+    packageStartupMessage("Please report any bugs to info@restriktor.org")
+}
+
+utils::globalVariables(c("Group", "Value", "green", "reset", 
+                         "Group_hypo_comparison", "Group_pop_values", 
+                         "sample_value", "x", "y"))
\ No newline at end of file
